#
# spec file for package python-sqlalchemy-migrate
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-sqlalchemy-migrate
Version:        0.13.0
Release:        6.3
Summary:        Database schema migration for SQLAlchemy
License:        MIT
Group:          Development/Libraries/Python
URL:            https://pypi.python.org/pypi/sqlalchemy-migrate
Source:         https://files.pythonhosted.org/packages/source/s/sqlalchemy-migrate/sqlalchemy-migrate-%{version}.tar.gz
Patch0:         support-sphinx-4.patch
Patch1:         setuptools-fixes.patch
# Test requirements:
#BuildRequires:  python-ScriptTest >= 1.0
BuildRequires:  %{python_module Tempita >= 0.4}
BuildRequires:  %{python_module decorator}
BuildRequires:  %{python_module pbr}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
# Documentation requirements:
BuildRequires:  python3-SQLAlchemy >= 0.9.6
BuildRequires:  python3-Sphinx
Requires:       python-SQLAlchemy >= 0.7.8
Requires:       python-Tempita >= 0.4
Requires:       python-decorator
Requires:       python-six >= 1.7.0
Requires:       python-sqlparse
Requires(post): update-alternatives
Requires(preun):update-alternatives
BuildArch:      noarch
%python_subpackages

%description
Inspired by Ruby on Rails' migrations, Migrate provides a way to deal with
database schema changes in SQLAlchemy projects.

Migrate extends SQLAlchemy to have database changeset handling. It provides a
database change repository mechanism which can be used from the command line as
well as from inside python code.

%package -n python-sqlalchemy-migrate-doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Provides:       %{python_module sqlalchemy-migrate-doc = %{version}}

%description -n python-sqlalchemy-migrate-doc
Inspired by Ruby on Rails' migrations, Migrate provides a way to deal with
database schema changes in SQLAlchemy projects.

Migrate extends SQLAlchemy to have database changeset handling. It provides a
database change repository mechanism which can be used from the command line as
well as from inside python code.

This package contains the documentation.

%prep
%setup -q -n sqlalchemy-migrate-%{version}
%autopatch -p1
find . -type f -name "*.py" -o -name "*.py_tmpl" | xargs sed -i "/#!/d" # Remove shebang from non-executable scripts
sed -i "s/, 'sphinxcontrib.issuetracker'//g" doc/source/conf.py # No internet access please

%build
%python_build
sphinx-build -b html doc/source doc/build/html && rm doc/build/html/.buildinfo && rm -r doc/build/html/.doctrees # Build HTML documentation

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/migrate
%python_clone -a %{buildroot}%{_bindir}/migrate-repository
%python_expand %fdupes %{buildroot}%{$python_sitelib}

#NOTE(saschpe): enable tests later, there are one or two upstream issues
#%%check
#python setup.py test

%post
%python_install_alternative migrate
%python_install_alternative migrate-repository

%postun
%python_uninstall_alternative migrate
%python_uninstall_alternative migrate-repository

%files %{python_files}
%license COPYING
%doc README.rst
%python_alternative %{_bindir}/migrate
%python_alternative %{_bindir}/migrate-repository
%{python_sitelib}/migrate
%{python_sitelib}/sqlalchemy_migrate-*

%files -n python-sqlalchemy-migrate-doc
%license COPYING
%doc doc/build/html

%changelog
* Tue Jan  9 2024 Dirk Müller <dmueller@suse.com>
- add setuptools-fixes.patch / switch to new python stack on SLE15
* Wed Feb 22 2023 Bernhard Wiedemann <bwiedemann@suse.com>
- Remove leftover Sphinx files for reproducible builds
* Thu Feb 16 2023 Dirk Müller <dmueller@suse.com>
- fix documentation invocation
* Wed Jul 21 2021 Steve Kowalik <steven.kowalik@suse.com>
- Add support-sphinx-4.patch:
  * Support Sphinx 4, stop using Sphinx 2.
* Fri Jul  2 2021 Matej Cepl <mcepl@suse.com>
- Temporarily use Sphinx2 (because of lp#1934504).
* Fri Dec 20 2019 Dirk Mueller <dmueller@suse.com>
- update to 0.13.0:
  * remove inspect.getargspec deprecation warning
  * Use engine.connect(); don't use private \_run\_visitor method
  * Claim support for python 3.6
  * Claim support for python 3.5
* Tue Apr 23 2019 Thomas Bechtold <tbechtold@suse.com>
- update to 0.12.0:
  * Change title in README.rst
  * Don't use deprecated / non-functional "force" parameter
  * Use legacy\_alter\_table ON in sqlite recreate\_table
  * Remove py26 support
  * Add .eggs in .gitignore
  * Import MutableMapping from the correct Python module
  * Update mailinglist from dev to discuss
  * Get rid of psycopg2 warnings by disabling wheels
  * Enforce that pbr used is >= 1.8
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Jan  5 2018 aplanas@suse.com
- Generate documentation via %%__python3 macro
* Mon Jul  3 2017 tbechtold@suse.com
- convert to singlespec
- split -doc package
* Thu Mar  9 2017 dmueller@suse.com
- update to 0.11.0:
  * Use a modern PBR package
  * Prepare for using standard python tests
  * Set autoincrement to False when modifying to non-Integer datatype
  * Raise VersionNotFoundError instead of KeyError
  * Fix DeprecationWarning on setuptools >= 11.3
  * Update .gitreview for new namespace
* Tue Sep  1 2015 tbechtold@suse.com
- update to 0.10.0:
  * Update URLs in documentation
  * Add VerNum.__index__() for Python 3 support
  * Fixes usage function for Py3
  * Unblock migrate (py26 and py3* testing issues)
  * Revert "Revert "uncap pbr and sqla requirements""
  * Update flake8 related dependencies
  * Revert "uncap pbr and sqla requirements"
  * uncap pbr and sqla requirements
  * Update tests and reqs for SQLA 1.0
  * Ignore stderr output when invoking migrate script in tests
  * Add Python 3 classifiers
- Adjust Requires according to requirements.txt
* Wed Apr 22 2015 tbechtold@suse.com
- update to 0.9.6:
  * Fix ibmdb2 index name handling
* Thu Feb 26 2015 tbechtold@suse.com
- update to version 0.9.5:
  * Don't run the test if _setup() fails
  * Correcting minor typo
  * Fix .gitignore for .tox and .testrepository
  * allow dropping fkeys with sqlite
  * Add pretty_tox setup
  * script: strip comments in SQL statements
* Tue Feb 24 2015 tbechtold@suse.com
- update to version 0.9.4:
  * Remove svn version tag setting
  * Ignore transaction management statements in SQL scripts
  * Use native sqlalchemy 0.9 quote attribute with ibmdb2
  * Don't add warnings filter on import
  * pep8: mark all pep8 checks that currently fail as ignored
* Tue Sep 16 2014 tbechtold@suse.com
- update to version 0.9.2:
  * SqlScript: execute multiple statements one by one
  * Make sure we don't throw away exception on SQL script failure
  * Pin testtools to < 0.9.36
- update Requires according to requirements.txt
* Mon May 12 2014 dmueller@suse.com
- update to 0.9.1:
  * Move patch from oslo to drop unique constraints with sqlite
  * Port to Python3
  * tests: Replace "self.assert_" by "self.assertTrue"
  * turn on testing for sqla 0.9
  * Replace AbstractType by TypeEngine
  * fix scripttest compat
  * Use native quote attribute introduced in sqla 0.9
  * Fix genmodel for SQLA 0.9
  * Conditionally import ibmdb2/ibm_db_sa
  * migrate needs subunit >= 0.0.18
  * UniqueConstraint named and escaped twice
  * Eradicate trailing whitespace
  * Convert tabs to spaces in a couple of rst files
* Thu Apr 10 2014 dmueller@suse.com
- Readd COPYING file
* Tue Dec  3 2013 speilicke@suse.com
- Use upstream URL again after 0.8.2 got finally published on PyPI.
* Tue Nov 19 2013 speilicke@suse.com
- Update to version 0.8.2:
  + Run tests on PostgreSQL and MySQL tooFix dropping of indexed columns in sqlite/sa08
  + Fix int overflow exception in unittest
  + Drop setuptools_git test requirement
  + Remove the tag_build line from setup.cfg
  + Fix the version number to match the last release.
  + Un-break the version in migrate/__init__.py
  + Fix broken development version link in README
- Use official PyPI release
* Thu Nov 14 2013 speilicke@suse.com
- Fix 12.2 build by catching all egg-info incarnations (either file
  or directory)
* Thu Nov 14 2013 speilicke@suse.com
- Change to Openstack upstream for SQLAlchemy-0.8+ support
- Add _service file, fix requirements
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Fri May 17 2013 speilicke@suse.com
- Fix dependencies
- Prerequisites for testsuite running
* Wed Jan 11 2012 rhafer@suse.de
- update to 0.7.2:
  * Changes:
  - support for SQLAlchemy 0.5.x has been dropped
  - Python 2.6 is the minimum supported Python version
  * Features
  - improved :pep:`8` compliance
  - optionally number versions with timestamps instead of
    sequences (partly pulled from Pete Keen)
  - allow descriptions in SQL change script filenames (by Pete
    Keen)
  - improved model generation
  * Fixed Bugs
  - api test downgrade/upgrade does not work with sql scripts
    (pulled from Yuen Ho Wong)
  - passing a unicode string as the migrate repository fails (add
    regression test)
  - make_update_script_for_model fails with AttributeError:
    'SchemaDiff' object has no attribute 'colDiffs' (patch by
    Jeremy Cantrell)
  - upgrade and downgrade functions are reversed when using the
    command "make_update_script_for_model" (patch by Jeremy
    Cantrell)
  - manage.py should use the "if __name__=='__main__'" trick
  - column creation in make_update_script_for_model and required
    API change (by Gabriel de Perthuis)
  - compare_model_to_db gets confused by sqlite_sequence (pulled
    from Dustin J. Mitchell)
  - drop column does not work on persistent sqlite databases
    (pulled from Benoît Allard)
  - table rename failure with sqlalchemy 0.7.x (patch by Mark
    McLoughlin)
  - update documentation and help text (pulled from Yuen Ho Wong)
* Wed Nov 30 2011 jdmulloy@gmail.com
- Fixed shebang removal code on .spec line 52
  * This line was indiscriminately deleting the 1st line of all .py
  and .py_tmpl file which caused it to delete things that were not
  shebangs. This causes errors when it deletes things like """
  before a doc string. For instance executing
  "from migrate import changeset" resulted in an
  Unexpected Indentation Error
* Tue Nov 29 2011 saschpe@suse.de
- Make it a noarch package
- Fixed dependencies
- Build HTML documentation and install that
* Tue Nov 29 2011 idoenmez@suse.de
- Cleanup spec file
- Use upstream tarball
* Wed Jul 20 2011 fisiu@opensuse.org
- update to 0.7.1
* Wed Apr  6 2011 hpj@urpla.net
- updated to 0.6.1
* Fri Jan  7 2011 hpj@urpla.net
- updated to 0.6
* Thu Jun  4 2009 cfarrell1980@gmail.com
- added to devel:languages:python
* Wed Mar  4 2009 cfarrell1980@gmail.com
- First import
